@@ -23,7 +23,7 @@ import copy
 import logging
 import os
 import warnings
-from typing import MutableMapping
+from collections.abc import MutableMapping
 from uuid import uuid4
 
 from ansible_compat.ports import cache, cached_property
@@ -55,7 +55,7 @@ def ansible_version() -> Version:
     return app.runtime.version
 
 
-# https://stackoverflow.com/questions/16017397/injecting-function-call-after-init-with-decorator  # noqa
+# https://stackoverflow.com/questions/16017397/injecting-function-call-after-init-with-decorator
 class NewInitCaller(type):
     """NewInitCaller."""
 
@@ -65,28 +65,32 @@ class NewInitCaller(type):
         return obj
 
 
-class Config(object, metaclass=NewInitCaller):
-    """
-    Config Class.
+class Config(metaclass=NewInitCaller):
+    """Config Class.
 
     Molecule searches the current directory for ``molecule.yml`` files by
     globbing `molecule/*/molecule.yml`.  The files are instantiated into
-    a list of Molecule :class:`.Config` objects, and each Molecule subcommand
+    a list of Molecule [molecule.config.Config][] objects, and each Molecule subcommand
     operates on this list.
 
     The directory in which the ``molecule.yml`` resides is the Scenario's
     directory.  Molecule performs most functions within this directory.
 
-    The :class:`.Config` object instantiates Dependency_, Driver_,
-    :ref:`lint`, Platforms_, Provisioner_, Verifier_,
-    :ref:`root_scenario`, and State_ references.
+    The [molecule.config.Config][] object instantiates Dependency, Driver,
+    Platforms, Provisioner, Verifier_,
+    [scenario][], and State_ references.
     """
 
     # pylint: disable=too-many-instance-attributes
     # Config objects should be allowed to have any number of attributes
-    def __init__(self, molecule_file: str, args={}, command_args={}, ansible_args=()):
-        """
-        Initialize a new config class and returns None.
+    def __init__(
+        self,
+        molecule_file: str,
+        args={},
+        command_args={},
+        ansible_args=(),
+    ) -> None:
+        """Initialize a new config class and returns None.
 
         :param molecule_file: A string containing the path to the Molecule file
          to be parsed.
@@ -133,6 +137,10 @@ class Config(object, metaclass=NewInitCaller):
     def is_parallel(self):
         return self.command_args.get("parallel", False)
 
+    @property
+    def platform_name(self):
+        return self.command_args.get("platform_name", None)
+
     @property
     def debug(self):
         return self.args.get("debug", MOLECULE_DEBUG)
@@ -199,20 +207,20 @@ class Config(object, metaclass=NewInitCaller):
             "MOLECULE_VERIFIER_TEST_DIRECTORY": self.verifier.directory,
         }
 
-    @cached_property
-    def lint(self):
-        lint_name = self.config.get("lint", None)
-        return lint_name
-
     @cached_property
     def platforms(self):
-        return platforms.Platforms(self, parallelize_platforms=self.is_parallel)
+        return platforms.Platforms(
+            self,
+            parallelize_platforms=self.is_parallel,
+            platform_name=self.platform_name,
+        )
 
     @cached_property
     def provisioner(self):
         provisioner_name = self.config["provisioner"]["name"]
         if provisioner_name == "ansible":
             return ansible.Ansible(self)
+        return None
 
     @cached_property
     def scenario(self):
@@ -220,6 +228,18 @@ class Config(object, metaclass=NewInitCaller):
 
     @cached_property
     def state(self):
+        myState = state.State(self)
+        # look at state file for molecule.yml date modified and warn if they do not match
+        if self.molecule_file and os.path.isfile(self.molecule_file):
+            modTime = os.path.getmtime(self.molecule_file)
+            if myState.molecule_yml_date_modified is None:
+                myState.change_state("molecule_yml_date_modified", modTime)
+            elif myState.molecule_yml_date_modified != modTime:
+                LOG.warning(
+                    f"The scenario config file ('{self.molecule_file}') has been modified since the scenario was created. "
+                    + "If recent changes are important, reset the scenario with 'molecule destroy' to clean up created items or "
+                    + "'molecule reset' to clear current configuration.",
+                )
         return state.State(self)
 
     @cached_property
@@ -227,15 +247,19 @@ class Config(object, metaclass=NewInitCaller):
         return api.verifiers(self).get(self.config["verifier"]["name"], None)
 
     def _get_driver_name(self):
+        # the state file contains the driver from the last run
         driver_from_state_file = self.state.driver
+        # the user may supply a driver on the command line
         driver_from_cli = self.command_args.get("driver_name")
+        # the driver may also be edited in the scenario
+        driver_from_scenario = self.config["driver"]["name"]
 
         if driver_from_state_file:
             driver_name = driver_from_state_file
         elif driver_from_cli:
             driver_name = driver_from_cli
         else:
-            driver_name = self.config["driver"]["name"]
+            driver_name = driver_from_scenario
 
         if driver_from_cli and (driver_from_cli != driver_name):
             msg = (
@@ -244,11 +268,25 @@ class Config(object, metaclass=NewInitCaller):
             )
             util.sysexit_with_message(msg)
 
+        if driver_from_state_file and driver_name not in api.drivers():
+            msg = (
+                f"Driver '{driver_name}' from state-file "
+                f"'{self.state.state_file}' is not available."
+            )
+            util.sysexit_with_message(msg)
+
+        if driver_from_scenario != driver_name:
+            msg = (
+                f"Driver '{driver_name}' is currently in use but the scenario config "
+                f"has changed and now defines '{driver_from_scenario}'. "
+                "To change drivers, run 'molecule destroy' for converged scenarios or 'molecule reset' otherwise."
+            )
+            LOG.warning(msg)
+
         return driver_name
 
     def _get_config(self) -> MutableMapping:
-        """
-        Perform a prioritized recursive merge of config files.
+        """Perform a prioritized recursive merge of config files.
 
         Returns a new dict.  Prior to merging the config files are interpolated with
         environment variables.
@@ -258,8 +296,7 @@ class Config(object, metaclass=NewInitCaller):
         return self._combine(keep_string=MOLECULE_KEEP_STRING)
 
     def _reget_config(self):
-        """
-        Perform the same prioritized recursive merge from `get_config`.
+        """Perform the same prioritized recursive merge from `get_config`.
 
         Interpolates the ``keep_string`` left behind in the original
         ``get_config`` call.  This is probably __very__ bad.
@@ -272,8 +309,7 @@ class Config(object, metaclass=NewInitCaller):
         return self._combine(env=env)
 
     def _combine(self, env=os.environ, keep_string=None) -> MutableMapping:
-        """
-        Perform a prioritized recursive merge of config files.
+        """Perform a prioritized recursive merge of config files.
 
         Returns a new dict.  Prior to merging the config files are interpolated with
         environment variables.
@@ -290,19 +326,19 @@ class Config(object, metaclass=NewInitCaller):
         for base_config in base_configs:
             with util.open_file(base_config) as stream:
                 s = stream.read()
-                self._preflight(s)
                 interpolated_config = self._interpolate(s, env, keep_string)
                 defaults = util.merge_dicts(
-                    defaults, util.safe_load(interpolated_config)
+                    defaults,
+                    util.safe_load(interpolated_config),
                 )
 
         if self.molecule_file:
             with util.open_file(self.molecule_file) as stream:
                 s = stream.read()
-                self._preflight(s)
                 interpolated_config = self._interpolate(s, env, keep_string)
                 defaults = util.merge_dicts(
-                    defaults, util.safe_load(interpolated_config)
+                    defaults,
+                    util.safe_load(interpolated_config),
                 )
 
         return defaults
@@ -345,6 +381,7 @@ class Config(object, metaclass=NewInitCaller):
             },
             "platforms": [],
             "prerun": True,
+            "role_name_check": 0,
             "provisioner": {
                 "name": "ansible",
                 "config_options": {},
@@ -390,7 +427,6 @@ class Config(object, metaclass=NewInitCaller):
                 "test_sequence": [
                     # dependency must be kept before lint to avoid errors
                     "dependency",
-                    "lint",
                     "cleanup",
                     "destroy",
                     "syntax",
@@ -413,13 +449,6 @@ class Config(object, metaclass=NewInitCaller):
             },
         }
 
-    def _preflight(self, data: MutableMapping):
-        env = set_env_from_file(os.environ.copy(), self.env_file)
-        errors, data = schema_v3.pre_validate(data, env, MOLECULE_KEEP_STRING)
-        if errors:
-            msg = f"Failed to pre-validate.\n\n{errors}"
-            util.sysexit_with_message(msg, detail=data)
-
     def _validate(self):
         msg = f"Validating schema {self.molecule_file}."
         LOG.debug(msg)
